/*			Beacon - Multiple Communication Route Message Center			*/

/* 				 designed and implemented by David A. Feldt					*/
/*					   President - Small Systems Guild						*/
/*				PO box 2751, Ann Arbor, MI 48106 (313) 996-4238				*/

/*	  The purpose of this header is to define all of the data structures 	*/
/*	  used in Red Ryder Host, allowing Beacon to simulate, translate, or	*/
/*	  back create Host compatable userlog, menu and message data files		*/

/* 			 Red Ryder Host designed and implemented by Scott Watson		*/
/*					copyright  1986,87 by The Freesoft Company				*/
/*				10828 Lacklink, St. Louis, MO  63114 (314) 423-2190			*/

/*		Beacon uses the following commercially licensed object libraries	*/

/*						Lightspeed C compiler 2.01							*/
/*					c-tree ISAM/B-Tree v4.1 release D						*/
/*					  Extender vol1 3.03, vol2 3.b1							*/
/*					   Communications Extender 1.a7							*/

/* DAF	created this file from Red Ryder Host doc 1.0 w/1.4 update	2/28/87	*/

#define		RRH_MAXMENUOPTS	80		/* max menu options per host menu file	*/

#define		RRH_MORE_EQUAL	0		/* user access must be >= accessLevel	*/
#define		RRH_LESS_EQUAL	1		/* user access must be <= accessLevel	*/
#define		RRH_EQUAL		2		/* user access must be  = accessLevel	*/

#define		RRH_ERASE_MASK	0x01	/* 0 = active, 1 = delete message flag 	*/
#define		RRH_REPLY_MASK	0x02	/* 0 = original, 1 = reply message flag */
#define		RRH_PRIV_MASK	0x04	/* 0 = public, 1 = private message flag */

#define		RRH_LINEFEED	0x01	/* 0 = CR only, 1 = CR and LF needed	*/
#define		RRH_CLEARSCREEN	0x02	/* clear screen with 0 = CRs, 1 = 0x0C 	*/
#define		RRH_HOTMENUS	0x80	/* 0 = CR, 1 = hot menus, no CR needed 	*/
#define		RRH_SYS1_MSG	0x10	/* 1 if system message 1 has been read	*/
#define		RRH_SYS2_MSG	0x20	/* 1 if system message 2 has been read	*/
#define		RRH_SYS3_MSG	0x40	/* 1 if system message 3 has been read	*/
#define		RRH_NEVERCLEAR	0x80	/* 1 = ignore bit 1, never clear screen	*/


struct	RRHOption {			/* Red Ryder Host menu option file format, v1.4	*/
			unsigned char	optionType;			/* activity command invokes	*/
			unsigned char	optionText[61];		/* command text description	*/
			unsigned char	optionChar;			/* select char user types	*/
			unsigned char	optionData[41];		/* command optional data	*/
			unsigned char	accessMod; 			/* >=, <= or = accessLevel	*/
			unsigned char	accessLevel;		/* user accessLevel needed	*/
		};
typedef struct	RRHOption	RRHOption;

struct	RRHMenu {			/* Red Ryder Host menu file format, version 1.4	*/
			unsigned char	title1[61];			/* first line of menu title	*/
			unsigned char	title2[61];			/* second line of menu title*/
			unsigned char	title3[61];			/* third line of menu title	*/
			unsigned char	optCount;	  		/* how many options follow	*/
			RRHOption		option[RRH_MAXMENUOPTS];/* variable length array*/
		};
typedef struct	HostMenu	HostMenu;

struct	RRHMessages {		/* Red Ryder Host message file format, v1.4		*/
			unsigned char	msgPath[50];  /* MSHHDR & MSGTXT files vol/path	*/
			long			lowMsg;				/* lowest message number	*/
			long			highMsg;			/* highest message number	*/
			long			reserved;			/* currently unused, rsrvd	*/
			unsigned char	msgSecTitle[20][26];/* 20 message section titles*/
			unsigned char	accessLevel[20];	/* msg section accessLevel	*/
			unsigned char	accessMod[20]; 		/* >=, <= or = accessLevel	*/
		};
typedef struct	RRHMessages	RRHMessages;

struct	RRHDateTime {		/* Red Ryder Host message date/time format,v1.4	*/
			unsigned char	month;  			/* month number  (01 to 12)	*/
			unsigned char	day;				/* day number    (01 to 31)	*/
			unsigned char	year;  				/* year number   (00 to 99)	*/
			unsigned char	hour;				/* hour number   (00 to 23)	*/
			unsigned char	minute;  			/* minute number (00 to 59)	*/
			unsigned char	second;				/* second number (00 to 59)	*/
		};
typedef struct	RRHDateTime	RRHDateTime;

struct	RRHTimeDate {		/* Red Ryder Host alternate date/time format 	*/
			unsigned char	month;  			/* month number  (01 to 12)	*/
			unsigned char	day;				/* day number    (01 to 31)	*/
			unsigned char	year;  				/* year number   (00 to 99)	*/
			unsigned char	hour;				/* hour number   (00 to 23)	*/
			unsigned char	minute;  			/* minute number (00 to 59)	*/
			unsigned char	second;				/* second number (00 to 59)	*/
		};
typedef struct	RRHTimeDate	RRHTimeDate;

struct	RRHMsgHdr {			/* Red Ryder Host message header format, v1.4	*/
			unsigned char	status;  			/* erase,reply,private bits	*/
			unsigned char	rsrv1;				/* currently unused, rsrvd	*/
			long			number;				/* message identity number	*/
			unsigned char	section;  			/* message section number	*/
			unsigned char	rsrv2;				/* currently unused, rsrvd	*/
			RRHDateTime		date;				/* time & date msg created	*/
			unsigned char	from[32];			/* who message came from	*/
			unsigned char	to[32];				/* who message addressed to	*/
			unsigned char	subject[42];		/* message subject text		*/
			long			textOffset;			/* byte offset into MSGTXT 	*/
			long			length;				/*message text size in bytes*/
			long			rsrv3;				/* currently unused, rsrvd	*/
		};
typedef struct	RRHMsgHdr	RRHMsgHdr;

struct	RRHUserlog {		/* Red Ryder Host userlog file format, v1.4		*/
			unsigned char	first[16];			/* user's first name		*/
			unsigned char	last[16];			/* user's last name			*/
			unsigned char	address[31];		/* city user calling from	*/
			unsigned char	password[9];		/* user selectable password	*/
			unsigned int	calls;  			/* total times user called	*/
			RRHTimeDate		date;				/* time of most recent call	*/
			unsigned char	timeLimit;			/* max minutes per session	*/
			unsigned char	accessLevel;		/* current user accessLevel	*/
			unsigned char	rsrv1[3];			/* currently unused, rsrvd	*/
			unsigned char	flags;				/* user preference flags	*/
			unsigned int	uploads;  			/* total user file uploads	*/
			unsigned int	downloads;  		/* total user file downloads*/
			unsigned int	privMsg;  			/* total private msgs sent	*/
			unsigned int	pubMsg;  			/* total public msgs sent	*/
			unsigned char	msgGrp1;			/* combined msg group  2-9	*/
			unsigned char	msgGrp2;			/* combined msg group 10-17	*/
			unsigned char	msgGrp3;			/* combined msg group 18-20	*/
			unsigned char	rsrv2[3];			/* currently unused, rsrvd	*/
		};
typedef struct	RRHUserlog	RRHUserlog;

