/*			Beacon - Multiple Communication Route Message Center			*/

/*					   private library header file							*/
/* 				  copyright  1987 Small Systems Guild 						*/

/*						Lightspeed C compiler 2.01							*/
/*					c-tree ISAM/B-Tree v4.1 release D						*/
/*					  Extender vol1 3.03, vol2 3.b1							*/
/*					   Communications Extender 1.a7							*/

/* 				 designed and implemented by David A. Feldt					*/
/*					   President - Small Systems Guild						*/
/*				PO box 2751, Ann Arbor, MI 48106 (313) 996-4238				*/

/* DAF	created the file from Polymath, ClipDemo, and other files	2/28/87	*/

#define		RRH_MAXMENUOPTS	80		/* max menu options per host menu file	*/

#define		RRH_MORE_EQUAL	0		/* user access must be >= accessLevel	*/
#define		RRH_LESS_EQUAL	1		/* user access must be <= accessLevel	*/
#define		RRH_EQUAL		2		/* user access must be  = accessLevel	*/

#define		RRH_ERASE_MASK	0x01	/* 0 = active, 1 = delete message flag 	*/
#define		RRH_REPLY_MASK	0x02	/* 0 = original, 1 = reply message flag */
#define		RRH_PRIV_MASK	0x04	/* 0 = public, 1 = private message flag */

Struct	RRHOption {			/* Red Ryder Host menu option file format, v1.4	*/
			unsigned char	optionType;			/* activity command invokes	*/
			unsigned char	optionText[61];		/* command text description	*/
			unsigned char	optionChar;			/* select char user types	*/
			unsigned char	optionData[41];		/* command optional data	*/
			unsigned char	accessMod; 			/* >=, <= or = accessLevel	*/
			unsigned char	accessLevel;		/* user accessLevel needed	*/
		};
typedef struct	RRHOption	RRHOption;

Struct	RRHMenu {			/* Red Ryder Host menu file format, version 1.4	*/
			unsigned char	title1[61];			/* first line of menu title	*/
			unsigned char	title2[61];			/* second line of menu title*/
			unsigned char	title3[61];			/* third line of menu title	*/
			unsigned char	optCount;	  		/* how many options follow	*/
			RRHOption		option[RRHMAXMENUOPTS];	/* variable length array*/
		};
typedef struct	HostMenu	HostMenu;

Struct	RRHMessages {		/* Red Ryder Host message file format, v1.4		*/
			unsigned char	msgPath[50];  /* MSHHDR & MSGTXT files vol/path	*/
			long			lowMsg;				/* lowest message number	*/
			long			highMsg;			/* highest message number	*/
			long			reserved;			/* currently unused, rsrvd	*/
			unsigned char	msgSecTitle[20][26];/* 20 message section titles*/
		};
typedef struct	RRHMessages	RRHMessages;

Struct	RRHDateTime {		/* Red Ryder Host message date/time format,v1.4	*/
			unsigned char	month;  			/* month number  (01 to 12)	*/
			unsigned char	day;				/* day number    (01 to 31)	*/
			unsigned char	year;  				/* year number   (00 to 99)	*/
			unsigned char	hour;				/* hour number   (00 to 23)	*/
			unsigned char	minute;  			/* minute number (00 to 59)	*/
			unsigned char	second;				/* second number (00 to 59)	*/
		};
typedef struct	RRHDateTime	RRHDateTime;

Struct	RRHMsgHdr {			/* Red Ryder Host message header format, v1.4	*/
			unsigned char	status;  			/* erase,reply,private bits	*/
			unsigned char	rsrv1;				/* currently unused, rsrvd	*/
			long			number;				/* message identity number	*/
			unsigned char	section;  			/* message section number	*/
			unsigned char	rsrv2;				/* currently unused, rsrvd	*/
			RRHDateTime		date;				/* time & date msg created	*/
			unsigned char	from[32];			/* who message came from	*/
			unsigned char	to[32];				/* who message addressed to	*/
			unsigned char	subject[42];		/* message subject text		*/
			long			textOffset;			/* byte offset into MSGTXT 	*/
			long			length;				/*message text size in bytes*/
		};
typedef struct	RRHMsgHdr	RRHMsgHdr;

Struct	RRHUserlog {		/* Red Ryder Host userlog file format, v1.4		*/
			unsigned char	first[16];			/* user's first name		*/
			unsigned char	last[16];			/* user's last name			*/
			unsigned char	address[31];		/* city user calling from	*/
			unsigned char	password[9];		/* user selectable password	*/
			unsigned int	calls;  			/* total times user called	*/
			RRHDateTime		date;				/* time of most recent call	*/
			unsigned char	timeLimit;			/* max minutes per session	*/
			unsigned char	accessLevel;		/* current user accessLevel	*/
			unsigned char	rsrv[3];			/* currently unused, rsrvd	*/
			unsigned char	flags;				/* user preference flags	*/
			unsigned int	uploads;  			/* total user file uploads	*/
			unsigned int	downloads;  		/* total user file downloads*/
			unsigned int	privMsg;  			/* total private msgs sent	*/
			unsigned int	pubMsg;  			/* total public msgs sent	*/
			unsigned char	msgGrp1;			/* combined msg group  2-9	*/
			unsigned char	msgGrp2;			/* combined msg group 10-17	*/
			unsigned char	msgGrp3;			/* combined msg group 18-20	*/
		};
typedef struct	RRHUserlog	RRHUserlog;

